;; Generated package description from org-notify.el  -*- no-byte-compile: t -*-
(define-package "org-notify" "0.1.0.0.20220804.122220" "Notifications for Org-mode" '((emacs "25.1")) :commit "bbd9a049ff3c3bb936a3044cf01949db2e4c91fd" :authors '(("Peter Münster" . "pm@a16n.net")) :maintainer '("Peter Münster" . "pm@a16n.net") :keywords '("notification" "todo-list" "alarm" "reminder" "pop-up" "calendar") :url "https://github.com/p-m/org-notify")
